*************
API Reference
*************

This chapter contains the API documentation for handyscope.

.. toctree::
   :maxdepth: 1

   api/library
   api/deviceList
   api/device
   api/generator
   api/i2cHost
   api/oscilloscope
   api/oscilloscopeChannel
   api/jitter_free

